// generated from rosidl_generator_c/resource/idl.h.em
// with input from actionlib_msgs:msg/GoalID.idl
// generated code does not contain a copyright notice

#ifndef ACTIONLIB_MSGS__MSG__GOAL_ID_H_
#define ACTIONLIB_MSGS__MSG__GOAL_ID_H_

#include "actionlib_msgs/msg/detail/goal_id__struct.h"
#include "actionlib_msgs/msg/detail/goal_id__functions.h"
#include "actionlib_msgs/msg/detail/goal_id__type_support.h"

#endif  // ACTIONLIB_MSGS__MSG__GOAL_ID_H_
